twall.console package
=====================

This package contains the console version of the application. Based on configuration parameters (usually loaded from
the command line), it periodically polls the Twitter API for new tweets using a specified query and prints them to
standard output until the user enters the character ``Q`` and presses ENTER.

Module contents
---------------

.. automodule:: twall.console
    :members:
    :undoc-members:
    :show-inheritance:
